import React, { useState, useEffect } from 'react';
import { useLocation } from 'react-router-dom';
import { db } from '../services/firebase-config';
import { collection, query, orderBy, limit, getDocs, addDoc, serverTimestamp } from 'firebase/firestore';
import HTMLPreview from '../components/HTMLPreview';
import EditPanel from '../components/EditPanel';
import SessionFooter from '../components/SessionFooter';
import { editHTMLWithAI } from '../services/openrouterApi';
import placeholder from '../assets/placeholder.png';
import './CurrentPage.css';

function CurrentPage() {
  const [currentHtml, setCurrentHtml] = useState('');
  const [selectedSection, setSelectedSection] = useState(null);
  const [sessionId, setSessionId] = useState(null);
  const [lastSaved, setLastSaved] = useState(null);
  const [error, setError] = useState('');
  const [isLoading, setIsLoading] = useState(true);
  const location = useLocation();

  useEffect(() => {
    const loadSession = async () => {
      try {
        const sid = location.state?.sessionId;
        if (!sid) {
          setIsLoading(false);
          return;
        }
        
        setSessionId(sid);
        
        const draftsRef = collection(db, `sessions/${sid}/drafts`);
        const q = query(draftsRef, orderBy('timestamp', 'desc'), limit(1));
        const snapshot = await getDocs(q);
        
        if (!snapshot.empty) {
          const latestDraft = snapshot.docs[0].data();
          setCurrentHtml(latestDraft.html);
          setLastSaved(latestDraft.timestamp?.toDate());
        }
      } catch (err) {
        console.error('Error loading session:', err);
        setError('Failed to load session');
      } finally {
        setIsLoading(false);
      }
    };

    loadSession();
  }, [location.state]);

  const handleSectionSelect = (sectionContent, index) => {
    setSelectedSection(sectionContent);
  };

  const handleEdit = async (section, transcribedText, editType) => {
    try {
      const editedHtml = await editHTMLWithAI(section, transcribedText);
      
      const updatedHtml = currentHtml.replace(section, editedHtml);
      setCurrentHtml(updatedHtml);
      
      await saveDraft(updatedHtml);
    } catch (err) {
      console.error('Edit error:', err);
      setError('Failed to process edit');
    }
  };

  const saveDraft = async (html) => {
    try {
      const draftsRef = collection(db, `sessions/${sessionId}/drafts`);
      const timestamp = serverTimestamp();
      
      await addDoc(draftsRef, {
        html,
        timestamp
      });
      
      setLastSaved(new Date());
    } catch (err) {
      console.error('Save error:', err);
      setError('Failed to save draft');
    }
  };

  if (isLoading) {
    return <div className="loading">Loading session...</div>;
  }

  if (!sessionId && !error) {
    return (
      <div className="placeholder-container">
        <img src={placeholder} alt="Import HTML to get started" />
      </div>
    );
  }

  if (error) {
    return <div className="error-container">{error}</div>;
  }

  return (
    <div className="current-page">
      <div className="edit-container">
        <HTMLPreview 
          html={currentHtml}
          onSectionSelect={handleSectionSelect}
        />
        <EditPanel
          selectedSection={selectedSection}
          onEdit={handleEdit}
          onUndo={() => {}}
          onRedo={() => {}}
        />
      </div>
      <SessionFooter
        sessionId={sessionId}
        lastSaved={lastSaved}
        onSave={() => saveDraft(currentHtml)}
      />
    </div>
  );
}

export default CurrentPage;

