import React, { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { db } from '../services/firebase-config';
import { collection, addDoc, serverTimestamp } from 'firebase/firestore';
import './ImportPage.css';

function ImportPage() {
  const navigate = useNavigate();
  const [formData, setFormData] = useState({
    title: '',
    type: 'agentx',
    folderUrl: '',
    tagToDivide: '',
    htmlContent: ''
  });
  const [isSubmitting, setIsSubmitting] = useState(false);
  const [error, setError] = useState('');

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setFormData(prevState => ({
      ...prevState,
      [name]: value
    }));
  };

  const processSVGs = (html) => {
    let svgs = [];
    let modifiedHtml = html;
    let svgCount = 0;
    
    const svgRegex = /<svg[^>]*>[\s\S]*?<\/svg>/gi;
    modifiedHtml = modifiedHtml.replace(svgRegex, (match) => {
      svgCount++;
      svgs.push({ id: `svg${svgCount}`, content: match });
      return `[SVG${svgCount}]`;
    });
    
    return { modifiedHtml, svgs };
  };

  const insertSeparators = (html) => {
    let sectionCount = 0;
    return html.replace(
      /(<section[^>]*>)/gi,
      (match) => {
        sectionCount++;
        return `SECTION${String(sectionCount).padStart(2, '0')}\n${match}`;
      }
    ) + `\nSECTION${String(sectionCount + 1).padStart(2, '0')}`;
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    setIsSubmitting(true);
    setError('');

    try {
      const { modifiedHtml, svgs } = processSVGs(formData.htmlContent);
      const htmlWithSeparators = insertSeparators(modifiedHtml);

      const sessionRef = await addDoc(collection(db, 'sessions'), {
        title: formData.title,
        type: formData.type,
        folderUrl: formData.folderUrl,
        tagToDivide: formData.tagToDivide,
        createdAt: serverTimestamp(),
        lastEdited: serverTimestamp()
      });

      await addDoc(collection(db, `sessions/${sessionRef.id}/drafts`), {
        html: htmlWithSeparators,
        timestamp: serverTimestamp()
      });

      for (const svg of svgs) {
        await addDoc(collection(db, `sessions/${sessionRef.id}/svgs`), {
          id: svg.id,
          content: svg.content
        });
      }

      navigate('/current', { state: { sessionId: sessionRef.id } });
    } catch (err) {
      console.error('Import error:', err);
      setError('Failed to import HTML. Please try again.');
    } finally {
      setIsSubmitting(false);
    }
  };

  return (
    <div className="import-page">
      <h2>Import HTML</h2>
      <form onSubmit={handleSubmit} className="import-form">
        <div className="form-group">
          <label htmlFor="title">Title:</label>
          <input
            type="text"
            id="title"
            name="title"
            value={formData.title}
            onChange={handleInputChange}
            required
          />
        </div>

        <div className="form-group">
          <label>Type:</label>
          <div className="radio-group">
            <label>
              <input
                type="radio"
                name="type"
                value="agentx"
                checked={formData.type === 'agentx'}
                onChange={handleInputChange}
              />
              Agent X
            </label>
            <label className="disabled">
              <input
                type="radio"
                name="type"
                value="raw"
                disabled
              />
              Raw Text
            </label>
            <label className="disabled">
              <input
                type="radio"
                name="type"
                value="html"
                disabled
              />
              All HTML
            </label>
          </div>
        </div>

        <div className="form-group">
          <label htmlFor="folderUrl">Folder URL:</label>
          <input
            type="text"
            id="folderUrl"
            name="folderUrl"
            value={formData.folderUrl}
            onChange={handleInputChange}
            placeholder="Optional - for future use"
          />
        </div>

        <div className="form-group">
          <label htmlFor="tagToDivide">Tag to divide:</label>
          <input
            type="text"
            id="tagToDivide"
            name="tagToDivide"
            value={formData.tagToDivide}
            onChange={handleInputChange}
            placeholder="Optional - for future use"
          />
        </div>

        <div className="form-group">
          <label htmlFor="htmlContent">HTML to import:</label>
          <textarea
            id="htmlContent"
            name="htmlContent"
            value={formData.htmlContent}
            onChange={handleInputChange}
            required
            rows={10}
          />
        </div>

        {error && <div className="error-message">{error}</div>}

        <button 
          type="submit" 
          className="import-button"
          disabled={isSubmitting}
        >
          {isSubmitting ? 'Importing...' : 'Import'}
        </button>
      </form>
    </div>
  );
}

export default ImportPage;

