import React, { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { db } from '../services/firebase-config';
import { collection, getDocs, orderBy, query } from 'firebase/firestore';
import './SessionsPage.css';

function SessionsPage() {
  const [sessions, setSessions] = useState([]);
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState('');
  const navigate = useNavigate();

  useEffect(() => {
    const fetchSessions = async () => {
      try {
        const sessionsRef = collection(db, 'sessions');
        const q = query(sessionsRef, orderBy('lastEdited', 'desc'));
        const snapshot = await getDocs(q);
        
        const sessionData = snapshot.docs.map(doc => ({
          id: doc.id,
          ...doc.data(),
          lastEdited: doc.data().lastEdited?.toDate()
        }));
        
        setSessions(sessionData);
      } catch (err) {
        console.error('Error fetching sessions:', err);
        setError('Failed to load sessions');
      } finally {
        setIsLoading(false);
      }
    };

    fetchSessions();
  }, []);

  const handleEditSession = (sessionId) => {
    navigate('/current', { state: { sessionId } });
  };

  const formatDate = (date) => {
    if (!date) return 'Never';
    return new Date(date).toLocaleString();
  };

  if (isLoading) {
    return <div className="loading">Loading sessions...</div>;
  }

  if (error) {
    return <div className="error">{error}</div>;
  }

  return (
    <div className="sessions-page">
      <h2>HTML Edit Sessions</h2>
      
      {sessions.length === 0 ? (
        <p className="no-sessions">No sessions found. Import some HTML to get started.</p>
      ) : (
        <table className="sessions-table">
          <thead>
            <tr>
              <th>Title</th>
              <th>Last Edited</th>
              <th>Preview</th>
              <th>Actions</th>
            </tr>
          </thead>
          <tbody>
            {sessions.map(session => (
              <tr key={session.id}>
                <td>{session.title}</td>
                <td>{formatDate(session.lastEdited)}</td>
                <td>
                  <button className="preview-button" disabled>
                    Preview
                  </button>
                </td>
                <td className="actions">
                  <button 
                    className="edit-button"
                    onClick={() => handleEditSession(session.id)}
                  >
                    Edit
                  </button>
                  <button className="download-button">
                    Download Page
                  </button>
                </td>
              </tr>
            ))}
          </tbody>
        </table>
      )}
    </div>
  );
}

export default SessionsPage;

